Documentation
¶
Index ¶
Constants ¶
const ( // RouteFormatDefault captures enum value "default" RouteFormatDefault string = "default" // RouteFormatHTTP captures enum value "http" RouteFormatHTTP string = "http" // RouteFormatJSON captures enum value "json" RouteFormatJSON string = "json" )
const ( // RouteTypeSync captures enum value "sync" RouteTypeSync string = "sync" // RouteTypeAsync captures enum value "async" RouteTypeAsync string = "async" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type App ¶
type App struct {
// Application annotations - this is a map of annotations attached to this app, keys must not exceed 128 bytes and must consist of non-whitespace printable ascii characters, and the seralized representation of individual values must not exeed 512 bytes
Annotations map[string]interface{} `json:"annotations,omitempty"`
// Application function configuration, applied to all routes.
Config map[string]string `json:"config,omitempty"`
// Time when app was created. Always in UTC.
// Read Only: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"created_at,omitempty"`
// App ID
// Read Only: true
ID string `json:"id,omitempty"`
// Name of this app. Must be different than the image name. Can ony contain alphanumeric, -, and _.
// Read Only: true
Name string `json:"name,omitempty"`
// A comma separated list of syslog urls to send all function logs to. supports tls, udp or tcp. e.g. tls://logs.papertrailapp.com:1
SyslogURL string `json:"syslog_url,omitempty"`
// Most recent time that app was updated. Always in UTC.
// Read Only: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updated_at,omitempty"`
}
App app swagger:model App
func (*App) MarshalBinary ¶
MarshalBinary interface implementation
func (*App) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type AppWrapper ¶
type AppWrapper struct {
// app
// Required: true
App *App `json:"app"`
// error
Error *ErrorBody `json:"error,omitempty"`
}
AppWrapper app wrapper swagger:model AppWrapper
func (*AppWrapper) MarshalBinary ¶
func (m *AppWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*AppWrapper) UnmarshalBinary ¶
func (m *AppWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type AppsWrapper ¶
type AppsWrapper struct {
// apps
// Required: true
Apps []*App `json:"apps"`
// error
Error *ErrorBody `json:"error,omitempty"`
// cursor to send with subsequent request to receive the next page, if non-empty
// Read Only: true
NextCursor string `json:"next_cursor,omitempty"`
}
AppsWrapper apps wrapper swagger:model AppsWrapper
func (*AppsWrapper) MarshalBinary ¶
func (m *AppsWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*AppsWrapper) UnmarshalBinary ¶
func (m *AppsWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Call ¶
type Call struct {
// App ID that is assigned to a route that is being executed.
// Read Only: true
AppID string `json:"app_id,omitempty"`
// Time when call completed, whether it was successul or failed. Always in UTC.
// Read Only: true
// Format: date-time
CompletedAt strfmt.DateTime `json:"completed_at,omitempty"`
// Time when call was submitted. Always in UTC.
// Read Only: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"created_at,omitempty"`
// Call execution error, if status is 'error'.
// Read Only: true
Error string `json:"error,omitempty"`
// Call UUID ID.
// Read Only: true
ID string `json:"id,omitempty"`
// App route that is being executed.
// Read Only: true
Path string `json:"path,omitempty"`
// Time when call started execution. Always in UTC.
// Read Only: true
// Format: date-time
StartedAt strfmt.DateTime `json:"started_at,omitempty"`
// A histogram of stats for a call, each is a snapshot of a calls state at the timestamp.
// Read Only: true
Stats []*Stat `json:"stats"`
// Call execution status.
// Read Only: true
Status string `json:"status,omitempty"`
}
Call call swagger:model Call
func (*Call) MarshalBinary ¶
MarshalBinary interface implementation
func (*Call) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type CallWrapper ¶
type CallWrapper struct {
// Call object.
// Required: true
Call *Call `json:"call"`
}
CallWrapper call wrapper swagger:model CallWrapper
func (*CallWrapper) MarshalBinary ¶
func (m *CallWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CallWrapper) UnmarshalBinary ¶
func (m *CallWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type CallsWrapper ¶
type CallsWrapper struct {
// calls
// Required: true
Calls []*Call `json:"calls"`
// error
Error *ErrorBody `json:"error,omitempty"`
// cursor to send with subsequent request to receive the next page, if non-empty
// Read Only: true
NextCursor string `json:"next_cursor,omitempty"`
}
CallsWrapper calls wrapper swagger:model CallsWrapper
func (*CallsWrapper) MarshalBinary ¶
func (m *CallsWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*CallsWrapper) UnmarshalBinary ¶
func (m *CallsWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Error ¶
type Error struct {
// error
Error *ErrorBody `json:"error,omitempty"`
}
Error error swagger:model Error
func (*Error) MarshalBinary ¶
MarshalBinary interface implementation
func (*Error) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type ErrorBody ¶
type ErrorBody struct {
// fields
// Read Only: true
Fields string `json:"fields,omitempty"`
// message
// Read Only: true
Message string `json:"message,omitempty"`
}
ErrorBody error body swagger:model ErrorBody
func (*ErrorBody) MarshalBinary ¶
MarshalBinary interface implementation
func (*ErrorBody) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type Log ¶
type Log struct {
// Call UUID ID
CallID string `json:"call_id,omitempty"`
// log
Log string `json:"log,omitempty"`
}
Log log swagger:model Log
func (*Log) MarshalBinary ¶
MarshalBinary interface implementation
func (*Log) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type LogWrapper ¶
type LogWrapper struct {
// Call log entry.
// Required: true
Log *Log `json:"log"`
}
LogWrapper log wrapper swagger:model LogWrapper
func (*LogWrapper) MarshalBinary ¶
func (m *LogWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*LogWrapper) UnmarshalBinary ¶
func (m *LogWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Route ¶
type Route struct {
// Route annotations - this is a map of annotations attached to this route, keys must not exceed 128 bytes and must consist of non-whitespace printable ascii characters, and the seralized representation of individual values must not exeed 512 bytes
Annotations map[string]interface{} `json:"annotations,omitempty"`
// App ID
AppID string `json:"app_id,omitempty"`
// Route configuration - overrides application configuration
Config map[string]string `json:"config,omitempty"`
// Max usable CPU cores for this route. Value in MilliCPUs (eg. 500m) or as floating-point (eg. 0.5)
Cpus string `json:"cpus,omitempty"`
// Time when route was created. Always in UTC.
// Read Only: true
// Format: date-time
CreatedAt strfmt.DateTime `json:"created_at,omitempty"`
// Payload format sent into function.
// Enum: [default http json]
Format string `json:"format,omitempty"`
// Map of http headers that will be sent with the response
Headers map[string][]string `json:"headers,omitempty"`
// Hot functions idle timeout before termination. Value in Seconds
IDLETimeout *int32 `json:"idle_timeout,omitempty"`
// Name of Docker image to use in this route. You should include the image tag, which should be a version number, to be more accurate. Can be overridden on a per route basis with route.image.
Image string `json:"image,omitempty"`
// Max usable memory for this route (MiB).
Memory uint64 `json:"memory,omitempty"`
// URL path that will be matched to this route
// Read Only: true
Path string `json:"path,omitempty"`
// Timeout for executions of this route. Value in Seconds
Timeout *int32 `json:"timeout,omitempty"`
// Route type
// Enum: [sync async]
Type string `json:"type,omitempty"`
// Most recent time that route was updated. Always in UTC.
// Read Only: true
// Format: date-time
UpdatedAt strfmt.DateTime `json:"updated_at,omitempty"`
}
Route route swagger:model Route
func (*Route) MarshalBinary ¶
MarshalBinary interface implementation
func (*Route) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type RouteWrapper ¶
type RouteWrapper struct {
// error
Error *ErrorBody `json:"error,omitempty"`
// message
Message string `json:"message,omitempty"`
// route
// Required: true
Route *Route `json:"route"`
}
RouteWrapper route wrapper swagger:model RouteWrapper
func (*RouteWrapper) MarshalBinary ¶
func (m *RouteWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RouteWrapper) UnmarshalBinary ¶
func (m *RouteWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type RoutesWrapper ¶
type RoutesWrapper struct {
// error
Error *ErrorBody `json:"error,omitempty"`
// cursor to send with subsequent request to receive the next page, if non-empty
// Read Only: true
NextCursor string `json:"next_cursor,omitempty"`
// routes
// Required: true
Routes []*Route `json:"routes"`
}
RoutesWrapper routes wrapper swagger:model RoutesWrapper
func (*RoutesWrapper) MarshalBinary ¶
func (m *RoutesWrapper) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*RoutesWrapper) UnmarshalBinary ¶
func (m *RoutesWrapper) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Stat ¶
type Stat struct {
// metrics
Metrics *StatMetrics `json:"metrics,omitempty"`
// timestamp
// Format: date-time
Timestamp strfmt.DateTime `json:"timestamp,omitempty"`
}
Stat stat swagger:model Stat
func (*Stat) MarshalBinary ¶
MarshalBinary interface implementation
func (*Stat) UnmarshalBinary ¶
UnmarshalBinary interface implementation
type StatMetrics ¶
type StatMetrics struct {
// cpu kernel
CPUKernel int64 `json:"cpu_kernel,omitempty"`
// cpu total
CPUTotal int64 `json:"cpu_total,omitempty"`
// cpu user
CPUUser int64 `json:"cpu_user,omitempty"`
// disk read
DiskRead int64 `json:"disk_read,omitempty"`
// disk write
DiskWrite int64 `json:"disk_write,omitempty"`
// mem limit
MemLimit int64 `json:"mem_limit,omitempty"`
// mem usage
MemUsage int64 `json:"mem_usage,omitempty"`
// net rx
NetRx int64 `json:"net_rx,omitempty"`
// net tx
NetTx int64 `json:"net_tx,omitempty"`
}
StatMetrics stat metrics swagger:model statMetrics
func (*StatMetrics) MarshalBinary ¶
func (m *StatMetrics) MarshalBinary() ([]byte, error)
MarshalBinary interface implementation
func (*StatMetrics) UnmarshalBinary ¶
func (m *StatMetrics) UnmarshalBinary(b []byte) error
UnmarshalBinary interface implementation
type Version ¶
type Version struct {
// version
// Read Only: true
Version string `json:"version,omitempty"`
}
Version version swagger:model Version
func (*Version) MarshalBinary ¶
MarshalBinary interface implementation
func (*Version) UnmarshalBinary ¶
UnmarshalBinary interface implementation